@@ -2,18 +2,25 @@ from __future__ import with_statement
 import unittest
 import sys
 from plumbum import SshMachine
+from plumbum.machines.paramiko_machine import ParamikoMachine
 from rpyc.utils.zerodeploy import DeployedServer
+try:
+    import paramiko  # noqa
+    _paramiko_import_failed = False
+except Exception:
+    _paramiko_import_failed = True
 
 
+@unittest.skipIf(_paramiko_import_failed, "Paramiko is not available")
 class TestDeploy(unittest.TestCase):
     def test_deploy(self):
         rem = SshMachine("localhost")
         SshMachine.python = rem[sys.executable]
         with DeployedServer(rem) as dep:
             conn = dep.classic_connect()
-            print (conn.modules.sys)
+            print(conn.modules.sys)
             func = conn.modules.os.getcwd
-            print (func())
+            print(func())
 
         try:
             func()
@@ -23,18 +30,12 @@ class TestDeploy(unittest.TestCase):
             self.fail("expected an EOFError")
 
     def test_deploy_paramiko(self):
-        try:
-            import paramiko     # @UnusedImport
-        except Exception:
-            self.skipTest("Paramiko is not available")
-        from plumbum.machines.paramiko_machine import ParamikoMachine
-
-        rem = ParamikoMachine("localhost", missing_host_policy = paramiko.AutoAddPolicy())
+        rem = ParamikoMachine("localhost", missing_host_policy=paramiko.AutoAddPolicy())
         with DeployedServer(rem) as dep:
             conn = dep.classic_connect()
-            print (conn.modules.sys)
+            print(conn.modules.sys)
             func = conn.modules.os.getcwd
-            print (func())
+            print(func())
 
         try:
             func()
