@@ -1,5 +1,4 @@
 import rpyc
-import time
 import sys
 import os
 import unittest
@@ -16,8 +15,13 @@ class Test_Ssh(unittest.TestCase):
             self.remote_machine = SshMachine("localhost")
         else:
             # assume "ssh localhost" is configured to run without asking for password
-            self.server = ThreadedServer(SlaveService, hostname = "localhost",
-                ipv6 = False, port = 18888, auto_register=False)
+            # `.ssh/config`
+            # Host localhost
+            #   HostName 127.0.0.1
+            #   User <username>
+            #   IdentityFile <id_rsa>
+            self.server = ThreadedServer(SlaveService, hostname="localhost",
+                                         ipv6=False, port=18888, auto_register=False)
             self.server._start_in_thread()
             self.remote_machine = SshMachine("localhost")
 
@@ -27,7 +31,7 @@ class Test_Ssh(unittest.TestCase):
 
     def test_simple(self):
         conn = rpyc.classic.ssh_connect(self.remote_machine, 18888)
-        print( "server's pid =", conn.modules.os.getpid())
+        print("server's pid =", conn.modules.os.getpid())
         conn.modules.sys.stdout.write("hello over ssh\n")
         conn.modules.sys.stdout.flush()
 
@@ -36,5 +40,6 @@ class Test_Ssh(unittest.TestCase):
         conn2.modules.sys.stdout.write("hello through rpyc.ssh_connect()\n")
         conn2.modules.sys.stdout.flush()
 
+
 if __name__ == "__main__":
     unittest.main()
