@@ -1,18 +1,18 @@
 import rpyc
 import os
 import unittest
-import time
 from rpyc.utils.authenticators import SSLAuthenticator
 from rpyc.utils.server import ThreadedServer
 from rpyc import SlaveService
-from nose import SkipTest
 
 try:
-    import ssl #@UnusedImport
+    import ssl  # noqa
+    _ssl_import_failed = False
 except ImportError:
-    raise SkipTest("requires ssl")
+    _ssl_import_failed = True
 
 
+@unittest.skipIf(_ssl_import_failed, "Ssl not available")
 class Test_SSL(unittest.TestCase):
     '''
     created key like that
@@ -22,13 +22,13 @@ class Test_SSL(unittest.TestCase):
     '''
 
     def setUp(self):
-        self.key = os.path.join( os.path.dirname(__file__) , "server.key")
-        self.cert =  os.path.join( os.path.dirname(__file__) , "server.crt")
-        print( self.cert, self.key )
+        self.key = os.path.join(os.path.dirname(__file__), "server.key")
+        self.cert = os.path.join(os.path.dirname(__file__), "server.crt")
+        print(self.cert, self.key)
 
         authenticator = SSLAuthenticator(self.key, self.cert)
-        self.server = ThreadedServer(SlaveService, port = 18812,
-            auto_register=False, authenticator = authenticator)
+        self.server = ThreadedServer(SlaveService, port=18812,
+                                     auto_register=False, authenticator=authenticator)
         self.server.logger.quiet = False
         self.server._start_in_thread()
 
@@ -36,15 +36,16 @@ class Test_SSL(unittest.TestCase):
         self.server.close()
 
     def test_ssl_conenction(self):
-        c = rpyc.classic.ssl_connect("localhost", port = 18812,
-            keyfile=self.key, certfile=self.cert)
-        print( repr(c) )
-        print( c.modules.sys )
-        print( c.modules["xml.dom.minidom"].parseString("<a/>") )
+        c = rpyc.classic.ssl_connect("localhost", port=18812,
+                                     keyfile=self.key, certfile=self.cert)
+        print(repr(c))
+        print(c.modules.sys)
+        print(c.modules["xml.dom.minidom"].parseString("<a/>"))
         c.execute("x = 5")
         self.assertEqual(c.namespace["x"], 5)
         self.assertEqual(c.eval("1+x"), 6)
         c.close()
 
+
 if __name__ == "__main__":
     unittest.main()
