@@ -1,6 +1,5 @@
 import os
 import rpyc
-import time
 import tempfile
 from rpyc.utils.server import ThreadedServer, ThreadPoolServer
 from rpyc import SlaveService
@@ -18,13 +17,14 @@ class Test_ThreadedServer(unittest.TestCase):
         self.server.close()
 
     def test_connection(self):
-        c = rpyc.classic.connect("localhost", port=18878)
-        print( c.modules.sys )
-        print( c.modules["xml.dom.minidom"].parseString("<a/>") )
-        c.execute("x = 5")
-        self.assertEqual(c.namespace["x"], 5)
-        self.assertEqual(c.eval("1+x"), 6)
-        c.close()
+        conn = rpyc.classic.connect("localhost", port=18878)
+        print(conn.modules.sys)
+        print(conn.modules["xml.dom.minidom"].parseString("<a/>"))
+        conn.execute("x = 5")
+        self.assertEqual(conn.namespace["x"], 5)
+        self.assertEqual(conn.eval("1+x"), 6)
+        conn.close()
+
 
 class Test_ThreadedServerOverUnixSocket(unittest.TestCase):
 
@@ -40,8 +40,8 @@ class Test_ThreadedServerOverUnixSocket(unittest.TestCase):
 
     def test_connection(self):
         c = rpyc.classic.unix_connect(self.socket_path)
-        print( c.modules.sys )
-        print( c.modules["xml.dom.minidom"].parseString("<a/>") )
+        print(c.modules.sys)
+        print(c.modules["xml.dom.minidom"].parseString("<a/>"))
         c.execute("x = 5")
         self.assertEqual(c.namespace["x"], 5)
         self.assertEqual(c.eval("1+x"), 6)
